{smcl}
{* *! version 1.1  13jan2012}{...}
{cmd:help apc}
{hline}

{title:Title}

{p2colset 5 20 22 2}{...}
{p 4 4 2}{hi:apc} {hline 2} Estimating age, period and cohort effects
{p2colreset}{...}

{title:Syntax}

{p 8 16 2}
{opt apc} {depvar} {ifin}{cmd:,} {opth a:ge(varname)} {opth p:eriod(varname)} {opth c:ohort(varname)} [{it:options}]


{synoptset 20 tabbed}{...}
{synopthdr}
{synoptline}
{syntab:Model}
{synopt :{opt method(identmethod)}}{it:identmethod} can be {opt dp} or {opt me}; default is {opt dp}{p_end}
{synopt :{opt l:owerbound(#)}}lower bound of dependent variable in the population; must be supplied if method is {opt me}{p_end}
{synopt :{opt u:pperbound(#)}}upper bound of dependent variable in the population; must be supplied if method is {opt me}{p_end}

{syntab:Estimation}
{synopt :{opt tech:nique(opttech)}}{it:opttech} can {opt nr}, {opt dfp}, {opt bfgs} or {opt nm}; default is {opt nr}{p_end}
{synopt :{opt ptol(#)}}{it:ptol} controls the optimization routine; default is {cmd:ptol(1e-10)}{p_end}
{synopt :{opt vtol(#)}}{it:vtol} controls the optimization routine; default is {cmd:vtol(1e-10)}{p_end}
{synopt :{opt maxiter(#)}}{it:maxiter} controls the optimization routine; default is {cmd:maxiter(2000000)}{p_end}

{syntab:Reporting}
{synopt :{opt graph(graphopt)}} controls whether to produce and save graphs; {it:graphopt} must be either {opt off} or {opt on, replace}; 
default is {opt off}{p_end}


{title:Description}

{pstd}
{cmd:apc} estimates the coffecients of the linear age-period-cohort (apc) model with dependent variable {it:depvar}.

{pstd}
The apc model aims to separate, for some outcome of interest, those influences associated with the process of aging, from those influences associated
with the date at which subjects are observed, from those influences associated with a subjects date of birth. In the linear apc model, whose coefficients are estimated by {cmd:apc}, the dependent variable is considered to be a linear additive 
fuction of dummies representing each age, period and cohort value observed in the sample.

{pstd}
The linear apc model suffers from a well-known fundamental identification
problem, namely that there is a perfect linear relationship between these effects: current year equals
year of birth plus age (in years).

{pstd}
{cmd:apc} estimates the coefficients using two methods that have been proposed. The first method is that of Deaton & Paxson (1994) 
which identifies the coefficients by imposing the restriction that the period effect is orthogonal to a trend and sums to zero. The second method is that of Browning, Crawford & Knoef (2010) which is based on a maximum entropy method and
can be applied when the dependent variable has a finite support in the population.

{title:Options}

{dlgtab:Model}

{phang}
{opt method(identmethod)}; Specifies which method to use for estimation. Allowed options for{it:identmethod} are:

{pmore}
{opt dp}: the parameters are identified using the restriction proposed by Deaton & Paxson (1994). This is the default.

{pmore}
{opt me}: the parameters are chosen based on a maximum entropy method proposed by Browning, Crawford & Knoef (2010). This method is applicable only if the dependent variable has a finite support in the population. 

{phang}
{opt l:owerbound(#)} The lower bound of the dependent variable in the population. Must be specified if the method used is {opt me}.

{phang}
{opt u:pperbound(#)} The upper bound of the dependent variable in the population. Must be specified if the method used is {opt me}.


{dlgtab:Estimation}

{phang}
{opt tech:nique(opttech)} If the method of estimation is {opt me} then, then the parameters are selected in order to maximise the entropy function. For details see Browning, Crawford & Knoef (2010). 
This maximisation uses STATA's {it:{help mf_optimize :optimize()}} routine.  The optimzation technique can be one of:

{col 16}{it:technique}{col 32}description
{col 16}{hline 54}
{col 16}{cmd:nr}{col 32}modified Newton-Raphson
{col 16}{cmd:dfp}{col 32}Davidon-Fletcher-Powell
{col 16}{cmd:bfgs}{col 32}Broyden-Fletcher-Goldfarb-Shanno
{col 16}{cmd:nm}{col 32}Nelder-Mead
{col 16}{hline 54}
{col 16}The default is {cmd:nr}.
{col 16}See {it:{help mf_optimize##i_technique :optimize_init_technique()}} for more details

{phang}
{opt ptol(#)} Controls the convergence criterion used by {it:{help mf_optimize :optimize()}}. See {it:{help mf_optimize##i_ptol:optimize_init_conv_ptol()}}. Default is {cmd:ptol(1e-10).}

{phang}
{opt vtol(#)} Controls the convergence criterion used by {it:{help mf_optimize :optimize()}}. See {it:{help mf_optimize##i_ptol:optimize_init_conv_vtol()}}. Default is {cmd:vtol(1e-10).}

{phang}
{opt maxiter(#)} Sets the maximum number of iterations allowed by {it:{help mf_optimize :optimize()}}. See {it:{help mf_optimize##i_maxiter:optimize_init_conv_maxiter()}}. Default is {cmd:maxiter(2000000).}

{dlgtab:Reporting}

{phang}
{opt graph(graphopt)}} controls whether to produce and save graphs. Allowed options for{it:graphopt} are:

{pmore}
{opt off} No graphs are displayed or saved. This is the default.

{pmore}
{opt on, replace} If this option is specified, four graphs are produced and saved in the current working directory. These are: a graph of the 
trajectory of the age effects, the period effects, the cohort effects and all three combined. 95% confidence intervals are included on the graphs. The first three of these are saved as {it: varname.gph} where {it: varname}
is the name of the age, period or cohort variable in the data. The graph that shows all three tractories is saved as {it: apc.gph}. These saved graphs will  overwrite
graphs of the same name in the current working directory - so for graphs to be produced {it: replace} has to specified as part of {it:graphopt}.


{title:Examples}

{phang}
These examples use the STATA example data set union.dta. The dependent variable is grade completed. This dependent variable 
has bounds in the population (between 0 and 18), so the maximum entropy method can be used.

{pstd}Open data{p_end}
{phang2}{cmd:. webuse union, clear}{p_end}

{pstd}Generate a cohort variable as year less age{p_end}
{phang2}{cmd:. gen cohort = year - age}{p_end}

{pstd}Estimating coefficients using maximum entropy approach{p_end}
{phang2}{cmd:. apc grade, age(age) period(year) cohort(cohort) method(me) lower(0) upper(18)}{p_end}

{pstd}Estimating coefficients using maximum entropy approach; displaying and saving graphs{p_end}
{phang2}{cmd:. apc grade, age(age) period(year) cohort(cohort) method(me) lower(0) upper(18) graph(on, replace)}{p_end}

{pstd}Estimating coefficients using Deaton and Paxson's method; displaying and saving graphs (note, no bounds required){p_end}
{phang2}{cmd:. apc grade, age(age) period(year) cohort(cohort) method(dp) graph(on, replace)}{p_end}

{pstd}Estimating coefficients using Deaton and Paxson's method; restricting the sample to those aged less than or equal to 30{p_end}
{phang2}{cmd:. apc grade if age<=30, age(age) period(year) cohort(cohort) method(dp) }{p_end}


{title:Saved results}

{pstd}
{cmd:apc} saves the following in {cmd:e()}:

{synoptset 20 tabbed}{...}
{p2col 5 20 24 2: Scalars}{p_end}
{synopt:{cmd:e(N)}}number of observations{p_end}

{synoptset 20 tabbed}{...}
{p2col 5 20 24 2: Macros}{p_end}
{synopt:{cmd:e(cmd)}}{cmd:apc}{p_end}

{synoptset 20 tabbed}{...}
{p2col 5 20 24 2: Matrices}{p_end}
{synopt:{cmd:e(b)}}coefficient vector{p_end}
{synopt:{cmd:e(V)}}variance-covariance matrix of the estimators{p_end}

{synoptset 20 tabbed}{...}
{p2col 5 20 24 2: Functions}{p_end}
{synopt:{cmd:e(sample)}}marks estimation sample{p_end}
{p2colreset}{...}


{title:A note on the identification of the apc coefficients}

{pstd}
The linear dependence that results in the identification problem comes from the fact that "age + year of birth = current year". 
However, some characteristics of the data, if present, can result in that equation not holding for everyone in the data.
In such a case the coefficients are identified without further restriction.
{cmd:apc} checks whether the parameters are identified without restriction and if so returns a message informing the user that this is the case. 
Estimation then proceeds using whichever method the user specified (i.e. {opt dp} or {opt me}). Whether one proceeds with a method such
as Deaton and Paxson's or the maximum entropy approach or one switches to OLS (or similar) depends on whether the identification restrictions (which may be
implicit in the data setup rather than explicitly imposed by the user) are credible.{p_end}

{pstd}
Two common reasons for the linear apc coefficients being identified without further restrestrictions are:

{pmore} {opt 1.} One of the age, period or cohort variables is denominated using a different time unit to the others. For example, age and period could be 
represented by dummies representing single years while cohort could be a dummy representing a particular decade. The 
identifying assumption here is that the cohort effect is the same for all those born in a particular decade. If the user is satisfied that this
is a credible assumption, then OLS (or similar) can be used.{p_end}

{pmore} {opt 2.} Due to the time of sampling the equation "age + year of birth = current year" might not hold. For example, if an
individual is born in December 1990 (so cohort = 1990), and they are surveyed in January 2012 (so period = 2012), their age in the data is 21. For 
this individual the equation above doesn't hold. The linear apc coefficients can be identified using OLS. Identification is coming from variation
in ages between individuals born in the same year. It will, in many applications, be difficult to justify this as an identification assumption.
{p_end}

{title:Citing {cmd:apc}}

{pstd}
The use of {cmd:apc} can be cited as follows:

{phang}
O'Dea, Cormac. 2012. "APC: Stata module to estimate age, period and cohort effects".
Available at: {browse www.ifs.org.uk/publications/5998}.

{title:Disclaimer}

{pstd}
THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.
SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY
SERVICING, REPAIR OR CORRECTION.

{pstd}
IN NO EVENT WILL THE COPYRIGHT HOLDERS OR THEIR EMPLOYERS, OR ANY OTHER
PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THIS SOFTWARE, BE LIABLE TO YOU
FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL
DAMAGES ARISING OUT OF THE ABILITY TO USE THE PROGRAM (INCLUDING BUT
NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES
SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE
WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PART BE ADVISED
OF THE POSSIBILITY OF SUCH DAMAGES. 


{title:Author}

{pstd}
Stata command {cmd:apc} was written by: Cormac O'Dea, Institute for Fiscal Studies. ({browse cormac_o@ifs.org.uk})

{title:References}

{phang}
Browning, M., Crawford, I. and Knoef, M. 2010. "The Age-Period-Cohort Problem; Set identification and point identification". Working Paper.
{browse "http://www.economics.ox.ac.uk/members/ian.crawford/papers/apc.pdf"}

{phang}
Deaton, Angus, and Christina Paxson. 1994. "Saving, Growth, and Aging in Taiwan,"
in D. Wise (ed) Studies in the Economics of Aging, pp. 331362 National Bureau of
Economic Research.

